==> nextcloud-app-calendar-1:5.5.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/be.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Каляндар",
    "Confirm" : "Пацвердзіць",
    "Description:" : "Апісанне:",
    "Date:" : "Дата:",
    "Where:" : "Дзе:",
    "Location:" : "Месцазнаходжанне:",
    "Duration:" : "Працягласць:",
    "Dates:" : "Даты:",
    "Next week" : "На наступным тыдні",
    "Event" : "Падзея",
    "Today" : "Сёння",
    "Year" : "Год",
    "Preview" : "Перадпрагляд",
    "Copy link" : "Скапіяваць спасылку",
    "Edit" : "Рэдагаваць",
    "Delete" : "Выдаліць",
    "Untitled calendar" : "Каляндар без назвы",
    "Calendars" : "Календары",
    "Export" : "Экспарт",
    "Name" : "Назва",
    "Deleted" : "Выдалены",
    "Restore" : "Аднавіць",
    "Delete permanently" : "Выдаліць назаўжды",
    "Share link" : "Абагуліць спасылку",
    "Copy public link" : "Скапіяваць публічную спасылку",
    "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "Save" : "Захаваць",
    "View" : "Праглядзець",
    "Filename" : "Назва файла",
    "Cancel" : "Скасаваць",
    "Timezone" : "Часавы пояс",
    "Navigation" : "Навігацыя",
    "Actions" : "Дзеянні",
    "Close editor" : "Закрыць рэдактар",
    "General" : "Агульныя",
    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
    "Show weekends" : "Паказаць уік-энды",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
    "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тыдзень","{duration} тыдні","{duration} тыдняў","{duration} тыдняў"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
    "Update" : "Абнавіць",
    "Location" : "Месцазнаходжанне",
    "Description" : "Апісанне",
    "Visibility" : "Бачнасць",
    "Duration" : "Працягласць",
    "Add" : "Дадаць",
    "Monday" : "Панядзелак",
    "Tuesday" : "Аўторак",
    "Wednesday" : "Серада",
    "Thursday" : "Чацвер",
    "Friday" : "Пятніца",
    "Saturday" : "Субота",
    "Sunday" : "Нядзеля",
    "Your name" : "Ваша імя",
    "Back" : "Назад",
    "Select conversation" : "Выберыце размову",
    "on" : "укл.",
    "Notification" : "Апавяшчэнне",
    "Email" : "Электронная пошта",
    "seconds" : "с",
    "Proceed" : "Працягнуць",
    "Upload from device" : "Запампаваць з прылады",
    "Delete file" : "Выдаліць файл",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Out of office" : "Па-за офісам",
    "Attendees:" : "Удзельнікі:",
    "local time" : "мясцовы час",
    "Done" : "Гатова",
    "Busy" : "Заняты",
    "Unknown" : "Невядомы",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "No attendees yet" : "Пакуль няма ўдзельнікаў",
    "Attendees" : "Удзельнікі",
    "Remove group" : "Выдаліць групу",
    "Remove attendee" : "Выдаліць удзельніка",
    "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
    "From" : "З",
    "To" : "Да",
    "never" : "ніколі",
    "Resources" : "Рэсурсы",
    "Attendance required" : "Наведванне абавязковае",
    "Attendance optional" : "Наведванне неабавязковае",
    "Remove participant" : "Выдаліць удзельніка",
    "Yes" : "Так",
    "No" : "Не",
    "Create" : "Ствараць",
    "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
    "Global" : "Глабальны",
    "Public calendars" : "Публічныя календары",
    "Invite" : "Запрасіць",
    "Discard changes?" : "Адхіліць змены?",
    "Untitled event" : "Падзея без назвы",
    "Close" : "Закрыць",
    "Selected" : "Выбрана",
    "Title" : "Загаловак",
    "15 min" : "15 хв",
    "30 min" : "30 хв",
    "60 min" : "60 хв",
    "90 min" : "90 хв",
    "Participants" : "Удзельнікі",
    "Submit" : "Адправіць",
    "Meeting" : "Сустрэча",
    "Daily" : "Штодня",
    "Weekly" : "Штотыдзень",
    "Monthly" : "Штомесяц",
    "Yearly" : "Штогод",
    "_Every %n day_::_Every %n days_" : ["Кожны %n дзень","Кожныя %n дні","Кожныя %n дзён","Кожныя %n дзён"],
    "_Every %n week_::_Every %n weeks_" : ["Кожны %n тыдзень","Кожныя %n тыдні","Кожныя %n тыдняў","Кожныя %n тыдняў"],
    "_Every %n month_::_Every %n months_" : ["Кожны %n месяц","Кожныя %n месяцы","Кожныя %n месяцаў","Кожныя %n месяцаў"],
    "_Every %n year_::_Every %n years_" : ["Кожны %n год","Кожныя %n года","Кожныя %n гадоў","Кожныя %n гадоў"],
    "_%n time_::_%n times_" : ["%n раз","%n разы","%n разоў","%n разоў"],
    "Untitled task" : "Задача без назвы",
    "%n more" : "%n яшчэ",
    "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
    "Other" : "Іншае",
    "Status" : "Статус",
    "Confirmed" : "Пацверджана",
    "Canceled" : "Скасавана",
    "Categories" : "Катэгорыі",
    "User not found" : "Карыстальнік не знойдзены",
    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-calendar-1:6.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/be.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Каляндар",
    "Confirm" : "Пацвердзіць",
    "Description:" : "Апісанне:",
    "Date:" : "Дата:",
    "Where:" : "Дзе:",
    "Location:" : "Месцазнаходжанне:",
    "Duration:" : "Працягласць:",
    "Dates:" : "Даты:",
    "Next week" : "На наступным тыдні",
    "Event" : "Падзея",
    "Today" : "Сёння",
    "Year" : "Год",
    "Preview" : "Перадпрагляд",
    "Copy link" : "Скапіяваць спасылку",
    "Edit" : "Рэдагаваць",
    "Delete" : "Выдаліць",
    "Untitled calendar" : "Каляндар без назвы",
    "Calendars" : "Календары",
    "New calendar with task list" : "Новы каляндар са спісам заданняў",
    "Export" : "Экспарт",
    "Name" : "Назва",
    "Deleted" : "Выдалены",
    "Restore" : "Аднавіць",
    "Delete permanently" : "Выдаліць назаўжды",
    "Share link" : "Абагуліць спасылку",
    "Copy public link" : "Скапіяваць публічную спасылку",
    "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "Save" : "Захаваць",
    "View" : "Праглядзець",
    "Filename" : "Назва файла",
    "Cancel" : "Скасаваць",
    "Timezone" : "Часавы пояс",
    "Navigation" : "Навігацыя",
    "Actions" : "Дзеянні",
    "Close editor" : "Закрыць рэдактар",
    "General" : "Агульныя",
    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
    "Show tasks in calendar" : "Паказаць заданні ў календары",
    "Show weekends" : "Паказваць уік-энды",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
    "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тыдзень","{duration} тыдні","{duration} тыдняў","{duration} тыдняў"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
    "Update" : "Абнавіць",
    "Location" : "Месцазнаходжанне",
    "Description" : "Апісанне",
    "Visibility" : "Бачнасць",
    "Duration" : "Працягласць",
    "to" : "на",
    "Add" : "Дадаць",
    "Monday" : "Панядзелак",
    "Tuesday" : "Аўторак",
    "Wednesday" : "Серада",
    "Thursday" : "Чацвер",
    "Friday" : "Пятніца",
    "Saturday" : "Субота",
    "Sunday" : "Нядзеля",
    "Your name" : "Ваша імя",
    "Back" : "Назад",
    "Select conversation" : "Выберыце размову",
    "on" : "укл.",
    "Notification" : "Апавяшчэнне",
    "Email" : "Электронная пошта",
    "seconds" : "с",
    "Proceed" : "Працягнуць",
    "Upload from device" : "Запампаваць з прылады",
    "Delete file" : "Выдаліць файл",
    "Confirmation" : "Пацвярджэнне",
    "Accepted {organizerName}'s invitation" : "Прынята запрашэнне {organizerName}",
    "Declined {organizerName}'s invitation" : "Адхілена запрашэнне {organizerName}",
    "{organizer} (organizer)" : "{organizer} (арганізатар)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Out of office" : "Па-за офісам",
    "Attendees:" : "Удзельнікі:",
    "local time" : "мясцовы час",
    "Done" : "Гатова",
    "Busy" : "Заняты",
    "Unknown" : "Невядомы",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "No attendees yet" : "Пакуль няма ўдзельнікаў",
    "Attendees" : "Удзельнікі",
    "Remove group" : "Выдаліць групу",
    "Remove attendee" : "Выдаліць удзельніка",
    "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
    "(organizer)" : "(арганізатар)",
    "From" : "З",
    "To" : "Да",
    "never" : "ніколі",
    "Resources" : "Рэсурсы",
    "Attendance required" : "Наведванне абавязковае",
    "Attendance optional" : "Наведванне неабавязковае",
    "Remove participant" : "Выдаліць удзельніка",
    "Yes" : "Так",
    "No" : "Не",
    "None" : "Няма",
    "Create" : "Ствараць",
    "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
    "Global" : "Глабальны",
    "Public calendars" : "Публічныя календары",
    "Personal" : "Асабістыя",
    "Show unscheduled tasks" : "Паказаць незапланаваныя заданні",
    "Unscheduled tasks" : "Незапланаваныя заданні",
    "Availability of {displayName}" : "Даступнасць {displayName}",
    "Invite" : "Запрасіць",
    "Discard changes?" : "Адхіліць змены?",
    "Untitled event" : "Падзея без назвы",
    "Close" : "Закрыць",
    "Selected" : "Выбрана",
    "Title" : "Загаловак",
    "15 min" : "15 хв",
    "30 min" : "30 хв",
    "60 min" : "60 хв",
    "90 min" : "90 хв",
    "Participants" : "Удзельнікі",
    "Submit" : "Адправіць",
    "Meeting" : "Сустрэча",
    "Daily" : "Штодня",
    "Weekly" : "Штотыдзень",
    "Monthly" : "Штомесяц",
    "Yearly" : "Штогод",
    "_Every %n day_::_Every %n days_" : ["Кожны %n дзень","Кожныя %n дні","Кожныя %n дзён","Кожныя %n дзён"],
    "_Every %n week_::_Every %n weeks_" : ["Кожны %n тыдзень","Кожныя %n тыдні","Кожныя %n тыдняў","Кожныя %n тыдняў"],
    "_Every %n month_::_Every %n months_" : ["Кожны %n месяц","Кожныя %n месяцы","Кожныя %n месяцаў","Кожныя %n месяцаў"],
    "_Every %n year_::_Every %n years_" : ["Кожны %n год","Кожныя %n года","Кожныя %n гадоў","Кожныя %n гадоў"],
    "_%n time_::_%n times_" : ["%n раз","%n разы","%n разоў","%n разоў"],
    "Untitled task" : "Заданне без назвы",
    "Please ask your administrator to enable the Tasks App." : "Папрасіце адміністратара ўключыць праграму Заданні.",
    "%n more" : "%n яшчэ",
    "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
    "Other" : "Іншае",
    "Status" : "Статус",
    "Confirmed" : "Пацверджана",
    "Canceled" : "Скасавана",
    "Categories" : "Катэгорыі",
    "Error while sharing file" : "Памылка пры абагульванні файла",
    "User not found" : "Карыстальнік не знойдзены",
    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
